PCB Environment: Data Fields - Functions

PCB Environment 2

Loading...
Searching...
No Matches
Here is a list of all functions with links to the structures/unions they belong to:

### - r -

- R() : GridDirection
- radius() : Via
- rangesOverlap() : Layer
- rasterize() : NavGrid
- rasterizeCompound() : NavGrid
- rasterizeFill() : Rasterizer< ROP >
- rasterizeLayoutAreaBorder() : NavGrid
- rasterizeLine() : Rasterizer< ROP >
- Rasterizer() : Rasterizer< ROP >
- rasterizeRanges() : Rasterizer< ROP >
- rasterizeTracks() : PCBoard
- RatsNest() : RatsNest
- rebuildTNG() : PCBoard
- recenter() : dsn::Shape
- recomputeComponentAreaBbox() : PCBoard
- rectify() : Segment_25, WideSegment_25
- redirect() : LogFile
- reduceBy_cells() : Track
- reduceSegmentsBy_cells() : Track
- reduceViaBy_cells() : Track
- referenceLen() : Connection
- refItem() : py::Object
- release() : py::NPArray< T >
- remove() : ActionSet, Net, PCBoard
- removeAndDisconnectPin() : Component
- removeChild() : Object
- removeConnection() : Pin
- removeEmptyNets() : PCBoard
- removeRoute() : NavTriangulation
- removeUnnecessaryPoints() : Path
- renamePinsWithSharedNames() : dsn::Data
- render() : Env, EnvPCB
- renumberComs() : PCBoard
- renumberNets() : PCBoard
- renumberPins() : PCBoard
- reserve() : BaseROP, RecordRangesROP
- reset() : Agent, AStarCosts, AStarVisitStatus, Env, EnvPCB, LubySequence, NavKeepoutCounts, py::ObjectRef, ResultCollection, ResultRecord, StateRepresentation, UIActions, UserAgent
- resetActionCount() : Agent
- resetActionLimit() : Agent
- resetKeepouts() : NavGrid
- resetKeepoutsRRR() : NavGrid
- resetKO() : NavPoint
- resetQuote() : DSNParserBase
- resetRasterizedCount() : Track
- resetZoom() : GLWidget
- resizeEvent() : GLWidget
- resizeTo1() : Path
- restore() : SignalContext
- restoreFlags() : NavPoint
- Result() : Action::Result
- ResultRecord() : ResultRecord
- reverse() : Connection, Path, Track
- RGBA() : Color
- RMSD() : Path
- rotateAround() : Object
- rotatedCcw() : GridDirection
- rotatedCcw45() : GridDirection
- rotatedCw45() : GridDirection
- route() : Pusher
- RouteLength() : rewards::RouteLength
- RoutePainter() : RoutePainter
- RoutePainterLines() : RoutePainterLines
- routePreview() : UIActions
- routeTo() : UIActions
- routeToPoint() : UIActions
- routeToPointPreview() : UIActions
- RouteTracker() : RouteTracker
- RRRAgent() : RRRAgent
- run() : Agent, RouteTracker
- run_agent() : Env, EnvPCB
- runAsync() : IUIApplication
- runPathFinding() : PCBoard
- runPathFindingTri() : PCBoard